var EventSystem = {
  ev: {
    GET_SERVER: 0,
    LOGIN: 1,
    MY_TEAM: 2,
    MY_LEAGUE: 3,
    MY_LEAGUE_MATCHES: 4
  },
  Launch: function(f) {
    setTimeout(f, 10);
  },
  Declare: function(ev) {
    switch (ev) {
      case EventSystem.ev.GET_SERVER :
        EventSystem.Launch("LiveFox.Login()");
        break;
      case EventSystem.ev.LOGIN :
        EventSystem.Launch("LiveFox.GetMyData()");
        break;
      case EventSystem.ev.MY_TEAM :
        EventSystem.Launch("LiveFox.GetLeague()");
        break;
      case EventSystem.ev.MY_LEAGUE :
        EventSystem.Launch("LiveFox.GetLeagueMatches()");
        break;
      case EventSystem.ev.MY_LEAGUE_MATCHES :
        EventSystem.Launch("LiveFox.GetMyMatch()");
        EventSystem.Launch("Friends.addLive()");
        EventSystem.Launch("LiveFox.startView()");
        break;
      default: 
        alert("EventSystem received an unknown event!");
        break;
    };
  }
};

/** --------------------------------------------
  * RequestManager
  * --------------------------------------------
  */
EventSystem.RequestManager =  {
  open: true,
  queue: new Array(), 
  RequestItem: function(r, d) {
    this.func = r;
    this.desc = d;
  },
  Add: function (request, description) {
    reqItem = new EventSystem.RequestManager.RequestItem(request, description);
    EventSystem.RequestManager.queue.push(reqItem);
    EventSystem.Launch("EventSystem.RequestManager.Dispatch()");
  },
  Dispatch: function () {
    if (!EventSystem.RequestManager.open) return;
    // locks RequestManager
    // unlocks in function EventSystem.HTTPRequestHandler 
    EventSystem.RequestManager.open=false;
    try {
      var request = EventSystem.RequestManager.queue.shift();
      if (request) {
        LiveFox.Log.Label(request.desc);
        request.func.send(null);
      } else {
        // there are no request. open RequestManager
        EventSystem.RequestManager.open=true;
      }
    } catch(e) {
      alert("EventSystem.RequestManager.Dispatch(): " + e);
    }
  },
  toString: function () {
    return ("[" + (EventSystem.RequestManager.open ? "open" : "close")+ "]" + this.queue);
  }
};

/** --------------------------------------------
  * XMLHTTPRequest
  * --------------------------------------------
  */
EventSystem.HTTPRequest = function(URL, responseParser, description) {
  var request = new XMLHttpRequest();
  netscape.security.PrivilegeManager.enablePrivilege("UniversalBrowserRead");
  request.open('GET', URL);
  request.setRequestHeader("User-Agent", HTTP.userAgent)
  request.overrideMimeType('text/xml');
  request.onreadystatechange = function() {
    EventSystem.HTTPRequestHandler(request, responseParser);
  };
  EventSystem.RequestManager.Add(request, description);
}
EventSystem.HTTPRequestHandler = function (request, responseParser) {
  var state, status, responseText, responseXML;
  try {
    state = request.readyState;
    LiveFox.Log.Meter(state*100/5);
    if (state==4) {
      status = request.status;
      if (status == 200) {
        responseText = request.responseText; 
        responseXML = request.responseXML;
        responseText = HTTP.Sanitize(responseText);
        responseParser(responseText, request);
        LiveFox.Log.Meter(100);
      } else {
        // there was an error returned by the server
        alert(LiveFox.Label.MESSAGE.HATTRICK_ERROR);
        LiveFox.Log.Meter(100);
      }
      EventSystem.RequestManager.open=true;
      EventSystem.Launch("EventSystem.RequestManager.Dispatch()");
    } else {
      // request isn't ready!
    }  
  } catch(e) {
    if (state==4) {
        LiveFox.Log.Meter(100);
    };
    EventSystem.RequestManager.open=true;
    EventSystem.Launch("EventSystem.RequestManager.Dispatch()");
  }
}
